@@ -1618,8 +1618,8 @@ class Update(MethodsInterface):
     def create_binhost_data(self):
         dv = self.clVars
         last_ts = dv.Get('cl_update_last_timestamp')
-        if (not dv.Get('cl_update_binhost_choice') and not dv.GetBool('update.cl_update_binhost_set')) \
-                or dv.Get('cl_update_binhost_choice') == 'auto':
+        if (not dv.Get('update.cl_update_binhost_choice') and not dv.GetBool('update.cl_update_binhost_set')) \
+                or dv.Get('update.cl_update_binhost_choice') == 'auto':
             if dv.Get('cl_update_binhost_stable_opt_set'):
                 binhost_list = dv.Get('cl_update_binhost_list')
             else:
@@ -1648,6 +1648,12 @@ class Update(MethodsInterface):
 
     @variable_module("update")
     def _search_best_binhost(self, binhosts_data, stabilization, ignore_level=False):
+        try:
+            if self.clVars.Get("cl_update_binhost_choice"):
+                self.clVars.Set('update.cl_update_binhost', self.clVars.Get("cl_update_binhost_choice"))
+                return self.clVars.Get("cl_update_binhost_choice")
+        except:
+            pass
         if not self.clVars.Get('cl_ebuild_phase'):
             logger = self._get_binhost_logger()
         if logger:
