@@ -932,6 +932,16 @@ class VariableClUpdateProfileDependUrl(FieldValue, ReadonlyVariable):
         self.label = _("URL")
 
 
+class VariableClUpdateProfileCheckSync(Variable):
+    urls = 'cl_update_rep_url'
+    names = 'cl_update_rep_name'
+
+    def get(self):
+        if not self.Get(self.urls) or not self.Get(self.names):
+            return False
+        return True
+
+
 class VariableClUpdateProfileRepName(ReadonlyVariable):
     type = "list"
 
@@ -1414,6 +1424,8 @@ class DataVarsUpdateProfile(SimpleDataVars):
             VariableClUpdateBinhostStableSet(section="update"),
             VariableClUpdateBinhostStableOptSet(section="update"),
             VariableClUpdateBinhostRevisionPath(section="update"),
+            VariableClUpdateRepHosting(section="update"),
+            VariableClUpdateBinhostSet(section="update"),
         )
         self['cl_profile_system'] = profile
         self['cl_chroot_path'] = chroot_path
